@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,45 +54,20 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 
 
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     TEXT = 258,
-     COMMENT = 259,
-     START = 260,
-     END = 261,
-     NAME = 262,
-     STRING = 263,
-     PROCINS = 264,
-     EMPTYEND = 265,
-     DOCTYPE = 266,
-     ENDINCL = 267
-   };
-#endif
-/* Tokens.  */
-#define TEXT 258
-#define COMMENT 259
-#define START 260
-#define END 261
-#define NAME 262
-#define STRING 263
-#define PROCINS 264
-#define EMPTYEND 265
-#define DOCTYPE 266
-#define ENDINCL 267
-
-
-
-
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 1 "html.y"
 
 /*
@@ -195,6 +169,9 @@ static void yyerror(const string s)
 
 
 
+/* Line 189 of yacc.c  */
+#line 174 "html.c"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -213,28 +190,66 @@ static void yyerror(const string s)
 # define YYTOKEN_TABLE 0
 #endif
 
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     TEXT = 258,
+     COMMENT = 259,
+     START = 260,
+     END = 261,
+     NAME = 262,
+     STRING = 263,
+     PROCINS = 264,
+     EMPTYEND = 265,
+     DOCTYPE = 266,
+     ENDINCL = 267
+   };
+#endif
+/* Tokens.  */
+#define TEXT 258
+#define COMMENT 259
+#define START 260
+#define END 261
+#define NAME 262
+#define STRING 263
+#define PROCINS 264
+#define EMPTYEND 265
+#define DOCTYPE 266
+#define ENDINCL 267
+
+
+
+
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 101 "html.y"
 {
+
+/* Line 214 of yacc.c  */
+#line 101 "html.y"
+
     string s;
     pairlist p;
-}
-/* Line 187 of yacc.c.  */
-#line 225 "html.c"
-	YYSTYPE;
+
+
+
+/* Line 214 of yacc.c  */
+#line 241 "html.c"
+} YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
 #endif
 
 
-
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 238 "html.c"
+/* Line 264 of yacc.c  */
+#line 253 "html.c"
 
 #ifdef short
 # undef short
@@ -309,14 +324,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -397,9 +412,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -433,12 +448,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -449,16 +464,16 @@ union yyalloc
 /* YYFINAL -- State number of the termination state.  */
 #define YYFINAL  3
 /* YYLAST -- Last index in YYTABLE.  */
-#define YYLAST   25
+#define YYLAST   27
 
 /* YYNTOKENS -- Number of terminals.  */
 #define YYNTOKENS  15
 /* YYNNTS -- Number of nonterminals.  */
 #define YYNNTS  9
 /* YYNRULES -- Number of rules.  */
-#define YYNRULES  22
+#define YYNRULES  23
 /* YYNRULES -- Number of states.  */
-#define YYNSTATES  32
+#define YYNSTATES  33
 
 /* YYTRANSLATE(YYLEX) -- Bison symbol number corresponding to YYLEX.  */
 #define YYUNDEFTOK  2
@@ -506,7 +521,7 @@ static const yytype_uint8 yyprhs[] =
 {
        0,     0,     3,     4,     7,    10,    13,    16,    19,    22,
       25,    28,    31,    32,    36,    40,    43,    44,    46,    50,
-      54,    57,    64
+      54,    57,    64,    70
 };
 
 /* YYRHS -- A `-1'-separated list of the rules' RHS.  */
@@ -518,7 +533,8 @@ static const yytype_int8 yyrhs[] =
       -1,    -1,     5,    20,    13,    -1,     5,    20,    10,    -1,
       21,    20,    -1,    -1,     7,    -1,     7,    14,     7,    -1,
        7,    14,     8,    -1,     6,    13,    -1,    11,     7,     7,
-       8,     8,    13,    -1,    11,     7,     7,     8,    13,    -1
+       8,     8,    13,    -1,    11,     7,     7,     8,    13,    -1,
+      11,     7,    13,    -1
 };
 
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
@@ -526,7 +542,7 @@ static const yytype_uint8 yyrline[] =
 {
        0,   114,   114,   114,   118,   119,   120,   121,   122,   123,
      124,   125,   126,   129,   130,   133,   134,   137,   140,   143,
-     148,   151,   152
+     148,   151,   152,   156
 };
 #endif
 
@@ -537,7 +553,7 @@ static const char *const yytname[] =
 {
   "$end", "error", "$undefined", "TEXT", "COMMENT", "START", "END",
   "NAME", "STRING", "PROCINS", "EMPTYEND", "DOCTYPE", "ENDINCL", "'>'",
-  "'='", "$accept", "start", "@1", "document", "starttag", "attributes",
+  "'='", "$accept", "start", "$@1", "document", "starttag", "attributes",
   "attribute", "endtag", "decl", 0
 };
 #endif
@@ -557,7 +573,7 @@ static const yytype_uint8 yyr1[] =
 {
        0,    15,    17,    16,    18,    18,    18,    18,    18,    18,
       18,    18,    18,    19,    19,    20,    20,    21,    21,    21,
-      22,    23,    23
+      22,    23,    23,    23
 };
 
 /* YYR2[YYN] -- Number of symbols composing right hand side of rule YYN.  */
@@ -565,7 +581,7 @@ static const yytype_uint8 yyr2[] =
 {
        0,     2,     0,     2,     2,     2,     2,     2,     2,     2,
        2,     2,     0,     3,     3,     2,     0,     1,     3,     3,
-       2,     6,     5
+       2,     6,     5,     3
 };
 
 /* YYDEFACT[STATE-NAME] -- Default rule to reduce with in state
@@ -575,8 +591,8 @@ static const yytype_uint8 yydefact[] =
 {
        2,     0,    12,     1,     0,    11,     5,     4,    16,     0,
        9,     0,    10,     6,     7,     8,    17,     0,    16,    20,
-       0,     0,    14,    13,    15,     0,    18,    19,     0,     0,
-      22,    21
+       0,     0,    14,    13,    15,     0,    23,    18,    19,     0,
+       0,    22,    21
 };
 
 /* YYDEFGOTO[NTERM-NUM].  */
@@ -587,19 +603,19 @@ static const yytype_int8 yydefgoto[] =
 
 /* YYPACT[STATE-NUM] -- Index in YYTABLE of the portion describing
    STATE-NUM.  */
-#define YYPACT_NINF -7
+#define YYPACT_NINF -6
 static const yytype_int8 yypact[] =
 {
-      -7,     8,    -7,    -7,     0,    -7,    -7,    -7,    10,    -3,
-      -7,    11,    -7,    -7,    -7,    -7,     5,     3,    10,    -7,
-      13,     7,    -7,    -7,    -7,    14,    -7,    -7,    -6,    12,
-      -7,    -7
+      -6,     7,    -6,    -6,     0,    -6,    -6,    -6,    12,     1,
+      -6,    13,    -6,    -6,    -6,    -6,     8,     3,    12,    -6,
+      -5,    10,    -6,    -6,    -6,    15,    -6,    -6,    -6,     2,
+      11,    -6,    -6
 };
 
 /* YYPGOTO[NTERM-NUM].  */
 static const yytype_int8 yypgoto[] =
 {
-      -7,    -7,    -7,    -7,    -7,     6,    -7,    -7,    -7
+      -6,    -6,    -6,    -6,    -6,     9,    -6,    -6,    -6
 };
 
 /* YYTABLE[YYPACT[STATE-NUM]].  What to do in state STATE-NUM.  If
@@ -609,16 +625,16 @@ static const yytype_int8 yypgoto[] =
 #define YYTABLE_NINF -4
 static const yytype_int8 yytable[] =
 {
-      -3,     5,    29,     6,     7,     8,     9,    30,     3,    10,
-      19,    11,    12,    22,    26,    27,    23,    16,    20,    21,
-      25,     0,    28,     0,    24,    31
+      -3,     5,    25,     6,     7,     8,     9,     3,    26,    10,
+      30,    11,    12,    22,    19,    31,    23,    27,    28,    16,
+      20,     0,    21,    29,    32,     0,     0,    24
 };
 
 static const yytype_int8 yycheck[] =
 {
-       0,     1,     8,     3,     4,     5,     6,    13,     0,     9,
-      13,    11,    12,    10,     7,     8,    13,     7,     7,    14,
-       7,    -1,     8,    -1,    18,    13
+       0,     1,     7,     3,     4,     5,     6,     0,    13,     9,
+       8,    11,    12,    10,    13,    13,    13,     7,     8,     7,
+       7,    -1,    14,     8,    13,    -1,    -1,    18
 };
 
 /* YYSTOS[STATE-NUM] -- The (internal number of the) accessing
@@ -627,8 +643,8 @@ static const yytype_uint8 yystos[] =
 {
        0,    16,    17,     0,    18,     1,     3,     4,     5,     6,
        9,    11,    12,    19,    22,    23,     7,    20,    21,    13,
-       7,    14,    10,    13,    20,     7,     7,     8,     8,     8,
-      13,    13
+       7,    14,    10,    13,    20,     7,    13,     7,     8,     8,
+       8,    13,    13
 };
 
 #define yyerrok		(yyerrstatus = 0)
@@ -813,17 +829,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -857,11 +876,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1141,10 +1160,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1160,11 +1177,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1172,9 +1188,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1198,14 +1214,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1213,51 +1254,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1287,7 +1305,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1295,7 +1312,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1318,9 +1334,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1331,7 +1346,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1341,6 +1355,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1349,16 +1366,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1390,20 +1407,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1443,56 +1456,78 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 114 "html.y"
     {data = handle.start();}
     break;
 
   case 3:
+
+/* Line 1455 of yacc.c  */
 #line 115 "html.y"
     {handle.end(data);}
     break;
 
   case 4:
+
+/* Line 1455 of yacc.c  */
 #line 118 "html.y"
     {handle.comment(data, (yyvsp[(2) - (2)].s));}
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 119 "html.y"
     {handle.text(data, (yyvsp[(2) - (2)].s));}
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 123 "html.y"
     {handle.pi(data, (yyvsp[(2) - (2)].s));}
     break;
 
   case 10:
+
+/* Line 1455 of yacc.c  */
 #line 124 "html.y"
     {handle.endincl(data);}
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 129 "html.y"
     {handle.starttag(data,(yyvsp[(1) - (3)].s),(yyvsp[(2) - (3)].p));}
     break;
 
   case 14:
+
+/* Line 1455 of yacc.c  */
 #line 130 "html.y"
     {handle.emptytag(data,(yyvsp[(1) - (3)].s),(yyvsp[(2) - (3)].p));}
     break;
 
   case 15:
+
+/* Line 1455 of yacc.c  */
 #line 133 "html.y"
     {(yyval.p) = (yyvsp[(1) - (2)].p); (yyval.p)->next = (yyvsp[(2) - (2)].p);}
     break;
 
   case 16:
+
+/* Line 1455 of yacc.c  */
 #line 134 "html.y"
     {(yyval.p) = NULL;}
     break;
 
   case 17:
+
+/* Line 1455 of yacc.c  */
 #line 137 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (1)].s);
@@ -1500,6 +1535,8 @@ yyreduce:
     break;
 
   case 18:
+
+/* Line 1455 of yacc.c  */
 #line 140 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (3)].s);
@@ -1507,6 +1544,8 @@ yyreduce:
     break;
 
   case 19:
+
+/* Line 1455 of yacc.c  */
 #line 143 "html.y"
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[(1) - (3)].s);
@@ -1514,16 +1553,22 @@ yyreduce:
     break;
 
   case 20:
+
+/* Line 1455 of yacc.c  */
 #line 148 "html.y"
     {handle.endtag(data, (yyvsp[(1) - (2)].s));}
     break;
 
   case 21:
+
+/* Line 1455 of yacc.c  */
 #line 151 "html.y"
     {handle.decl(data, (yyvsp[(2) - (6)].s), (yyvsp[(4) - (6)].s), (yyvsp[(5) - (6)].s));}
     break;
 
   case 22:
+
+/* Line 1455 of yacc.c  */
 #line 152 "html.y"
     {if (strcasecmp((yyvsp[(3) - (5)].s), "public") == 0)
 					   handle.decl(data, (yyvsp[(2) - (5)].s), (yyvsp[(4) - (5)].s), NULL);
@@ -1531,9 +1576,17 @@ yyreduce:
 					   handle.decl(data, (yyvsp[(2) - (5)].s), NULL, (yyvsp[(4) - (5)].s));}
     break;
 
+  case 23:
 
-/* Line 1267 of yacc.c.  */
-#line 1537 "html.c"
+/* Line 1455 of yacc.c  */
+#line 156 "html.y"
+    {handle.decl(data, (yyvsp[(2) - (3)].s), NULL, NULL);}
+    break;
+
+
+
+/* Line 1455 of yacc.c  */
+#line 1590 "html.c"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1544,7 +1597,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1609,7 +1661,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1626,7 +1678,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1683,9 +1735,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1710,7 +1759,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1721,7 +1770,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
