@@ -153,9 +153,10 @@ void handle_text(void *clientdata, string text)
 void handle_decl(void *clientdata, string gi,
 		 string fpi, string url)
 {
-  if (!url) fprintf(out, "<!DOCTYPE %s PUBLIC \"%s\">", gi, fpi);
-  else if (!fpi) fprintf(out, "<!DOCTYPE %s SYSTEM \"%s\">", gi, url);
-  else fprintf(out, "<!DOCTYPE %s PUBLIC \"%s\" \"%s\">", gi, fpi, url);
+  fprintf(out, "<!DOCTYPE %s", gi);
+  if (fpi) fprintf(out, " PUBLIC \"%s\"", fpi);
+  if (url) fprintf(out, " %s\"%s\"", fpi ? "" : "SYSTEM ", url);
+  fprintf(out, ">");
 }
 
 
