@@ -227,9 +227,9 @@ void handle_text(void *clientdata, string text)
 void handle_decl(void *clientdata, string gi, string fpi, string url)
 {
   printf("<!DOCTYPE %s", gi);
-  if (!fpi) printf(" SYSTEM \"%s\">", url);
-  else if (!url) printf(" PUBLIC \"%s\">", fpi);
-  else printf(" PUBLIC \"%s\" \"%s\">", fpi, url);
+  if (fpi) printf(" PUBLIC \"%s\"", fpi);
+  if (url) printf(" %s\"%s\"", fpi ? "" : "SYSTEM ", url);
+  printf(">");
   free(gi);
   free(fpi);
   free(url);
