@@ -37,7 +37,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 11 Apr 2000
- * Version: $Id: hxindex.c,v 1.9 2010/01/15 00:23:24 bbos Exp $
+ * Version: $Id: hxindex.c,v 1.12 2011/03/17 19:19:23 bbos Exp $
  *
  **/
 #include <config.h>
@@ -123,6 +123,7 @@ static string globalurlprevious;/* Must be global for twalk */
 static Boolean bctarget = True;	/* Add <A name=> after IDs */
 static Boolean use_secno = False; /* Anchor text is "#" instead of section # */
 static Boolean final = False;	/* Leave used attributes in document */
+static Boolean trim_punct = True; /* Remove trailing punctuation from terms */
 
 
 /* handle_error -- called when a parse error occurred */
@@ -197,15 +198,49 @@ static void handle_endtag(void *clientdata, string name)
   tree = html_pop(tree, name);
 }
 
-/* trim -- remove leading and trailing white space */
+/* trim -- remove leading and trailing white space, collapse white space */
 static void trim(string s)
 {
+#if 1
+  string t;
+  int i, j;
+
+  t = newstring(s);
+  for (i = 0; isspace(t[i]); i++); /* Skip leading white space */
+  for (j = 0; t[i]; i++)
+    if (!isspace(t[i])) s[j++] = t[i];
+    else if (!isspace(t[i-1])) s[j++] = ' ';
+  if (j == 0) s[j] = '\0';
+  else if (isspace(s[j-1])) s[j-1] = '\0';
+  else s[j] = '\0';
+  dispose(t);
+#endif
+
+#if 0
+  int i, j;
+  Boolean atspace;
+
+  atspace = True;
+  j = strlen(s);
+  i = 0;
+  while (s[i]) {
+    if (!isspace(s[i])) {atspace = False; i++;}
+    else if (!atspace) {s[i] = ' '; atspace = True; i++;}
+    else {memmove(s + i, s + i + 1, j - i); j--;}
+  }
+  if (j == 0) s[j] = '\0';
+  else if (atspace) s[j-1] = '\0';
+  else s[j] = '\0';
+#endif
+
+#if 0
   int i, j;
 
   for (i = 0; isspace(s[i]); i++);
   for (j = strlen(s); j > i && isspace(s[j-1]); j--);
   if (i != 0) memmove(s, s + i, j - i);
   s[j-i] = '\0';
+#endif
 }
 
 /* parse_subterms -- parse s to create terms & sortkeys array in an Indexterm */
@@ -219,6 +254,7 @@ static void parse_subterms(const Indexterm term, const conststring s)
 
   /* Create the terms array and count the number of subterms */
   h = newstring(s);
+  trim(h);
   term->nrkeys = 1;
   newarray(term->terms, 1);
   term->terms[0] = h;
@@ -274,6 +310,14 @@ static void parse_subterms(const Indexterm term, const conststring s)
     }
     *q = '\0';
 
+    if (trim_punct) {
+      /* Remove some trailing white space and punctuation */
+      for (q--; q != h && strspn(q, " \r\n\t\f\v,:;!?"); q--) *q = '\0';
+
+      /* Remove final '.' only if it is the only '.' in the term */
+      if ((q = strrchr(h, '.')) && !*(q+1) && q == strchr(h, '.')) *q = '\0';
+    }
+
     /* Then convert from UTF-8 to wchar_t */
     cd = iconv_open("wchar_t", "UTF-8");
     if (cd == (iconv_t)(-1)) {perror("hxindex"); exit(1);}
@@ -467,8 +511,8 @@ static void expand(Tree t, Boolean *write, Indexterm terms)
 	break;
       case Declaration:
 	printf("<!DOCTYPE %s", h->name);
-	if (h->text) printf(" PUBLIC \"%s\"", h->text);	else printf(" SYSTEM");
-	if (h->url) printf(" \"%s\"", h->url);
+	if (h->text) printf(" PUBLIC \"%s\"", h->text);
+	if (h->url) printf(" %s\"%s\"", h->text ? "" : "SYSTEM ", h->url);
 	printf(">");
 	break;
       case Procins:
@@ -758,7 +802,7 @@ int main(int argc, char *argv[])
   Boolean write = True;
   Indexterm termtree = NULL;	/* Sorted tree of terms */
   string secno;
-  char c;
+  int c;
 
   /* Bind the parser callback routines to our handlers */
   set_error_handler(handle_error);
@@ -774,7 +818,7 @@ int main(int argc, char *argv[])
 
   yyin = NULL;
 
-  while ((c = getopt(argc, argv, "txbi:cnf")) != -1)
+  while ((c = getopt(argc, argv, "txbi:cnfr")) != -1)
   switch (c) {
   case 't': bctarget = False; break; /* Don't write <a name> after each ID */
   case 'x': xml = True; break;	/* Output as XML */
@@ -783,10 +827,11 @@ int main(int argc, char *argv[])
   case 'c': userclassnames = tokenize(optarg); break; /* Set class names */
   case 'n': use_secno = True; break; /* Print section numbers instead of "#" */
   case 'f': final = True; break; /* "Final": remove used attributes */
+  case 'r': trim_punct = False; break; /* Do not remove trailing punctuation */
   default: usage(argv[0]);
   }
   if (optind == argc) yyin = stdin;
-  else if (optind >= argc) usage(argv[0]);
+  else if (argc > optind + 1) usage(argv[0]);
   else if (eq(argv[optind], "-")) yyin = stdin;
   else yyin = fopenurl(argv[optind], "r");
 
