@@ -6,7 +6,7 @@
  *
  * Created 9 May 1998
  * Bert Bos <bert@w3.org>
- * $Id: hxnormalize.c,v 1.5 2009/10/06 20:03:15 bbos Exp $
+ * $Id: hxnormalize.c,v 1.6 2010/05/04 21:17:40 bbos Exp $
  */
 #include <config.h>
 #include <stdio.h>
@@ -36,6 +36,7 @@ static Boolean do_endtag = False;
 static Boolean has_errors = False;
 static Boolean do_doctype = True;
 static Boolean clean_span = False;
+static string long_comment = NULL;
 
 
 /* handle_error -- called when a parse error occurred */
@@ -168,6 +169,11 @@ static void pp(Tree n, Boolean preformatted, Boolean allow_text)
       }
       break;
     case Comment:
+      if (long_comment && strstr(n->text, long_comment) && !preformatted) {
+	/* Found a comment that should have an empty line before it */
+	outbreak();
+	outln(NULL, True);
+      }
       out("<!--", True); out(n->text, True);
       if (allow_text || preformatted) out("-->", True);
       else outln("-->", preformatted);
@@ -180,9 +186,9 @@ static void pp(Tree n, Boolean preformatted, Boolean allow_text)
 	  out(" PUBLIC \"", False);
 	  out(n->text, False);
 	  out("\"", False);
-	} else
-	  out(" SYSTEM", False);
+	}
 	if (n->url) {
+	  if (!n->text) out(" SYSTEM", False);
 	  out(" \"", False);
 	  out(n->url, False);
 	  out("\"", False);
@@ -260,7 +266,7 @@ static void prettyprint(Tree t)
 static void usage(string prog)
 {
   fprintf(stderr, "%s version %s\n\
-Usage: %s [-e] [-d] [-x] [-i indent] [-l linelen] [file_or_url]\n",
+Usage: %s [-e] [-d] [-x] [-i indent] [-l linelen] [-c commentmagic] [file_or_url]\n",
 	  prog, VERSION, prog);
   exit(1);
 }
@@ -282,7 +288,7 @@ int main(int argc, char *argv[])
   set_emptytag_handler(handle_emptytag);
   set_endtag_handler(handle_endtag);
 
-  while ((c = getopt(argc, argv, "edxi:l:s")) != -1)
+  while ((c = getopt(argc, argv, "edxi:l:sc:")) != -1)
     switch (c) {
     case 'e': do_endtag = True; break;
     case 'x': do_xml = True; break;
@@ -290,6 +296,7 @@ int main(int argc, char *argv[])
     case 'i': set_indent(atoi(optarg)); break;
     case 'l': set_linelen(atoi(optarg)); break;
     case 's': clean_span = True; break;
+    case 'c': long_comment = optarg; break;
     default: usage(argv[0]);
     }
   if (optind == argc) yyin = stdin;
