@@ -22,7 +22,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 4 August 2000
- * Version: $Id: hxref.c,v 1.4 2010/04/27 14:30:54 bbos Exp $
+ * Version: $Id: hxref.c,v 1.5 2010/11/17 22:40:01 bbos Exp $
  **/
 
 #include <config.h>
@@ -265,7 +265,6 @@ static void find_instances(Tree tree)
 {
   ENTRY entry, *e;
   conststring title;
-  Node *h;
 
   if (!tree) return;
 
@@ -336,8 +335,7 @@ static void write_doc(Tree n, Boolean do_xml, FILE *f)
     case Declaration:
       fprintf(f, "<!DOCTYPE %s", n->name);
       if (n->text) fprintf(f, " PUBLIC \"%s\"", n->text);
-      else fprintf(f, " SYSTEM");
-      if (n->url) fprintf(f, " \"%s\"", n->url);
+      if (n->url) fprintf(f, " %s\"%s\"", n->text ? "" : "SYSTEM ", n->url);
       fprintf(f, ">");
       break;
     case Procins:
