@@ -327,8 +327,8 @@ static void expand(Tree t, Boolean *write, Boolean exp, Boolean keep_anchors)
 	break;
       case Declaration:
 	printf("<!DOCTYPE %s", h->name);
-	if (h->text) printf(" PUBLIC \"%s\"", h->text);	else printf(" SYSTEM");
-	if (h->url) printf(" \"%s\"", h->url);
+	if (h->text) printf(" PUBLIC \"%s\"", h->text);
+	if (h->url) printf(" %s\"%s\"", h->text ? "" : "SYSTEM ", h->url);
 	printf(">");
 	break;
       case Procins:
