@@ -89,24 +89,28 @@ static void put_attr(void)
 static void put_decl(const string buf)
 {
   int i;
+  Boolean has_fpi = False;
 
   assert(buf[0] == '!');
   printf("<!DOCTYPE ");
   /* write name of root element */
   for (i = 1; buf[i] && buf[i] != ' '; i++) putchar(buf[i]);
-  if (! buf[i]) errexit("Incorrect DOCTYPE declaration: %s\n", buf);
-  if (buf[++i] != '"') errexit("Incorrect DOCTYPE declaration: %s\n", buf);
   /* write FPI if present */
-  if (buf[++i] != '"') {			/* FPI */
+  while (buf[i] == ' ') i++;
+  if (buf[i] != '"') errexit("Incorrect DOCTYPE declaration: %s\n", buf);
+  if (buf[++i] != '"') {
+    has_fpi = True;
     printf(" PUBLIC \"");
     for (; buf[i] && buf[i] != '"'; i++) putchar(buf[i]);
     putchar('"');
-  } else {					/* No FPI */
-    printf(" SYSTEM");
   }
-  if (! buf[i]) errexit("Incorrect DOCTYPE declaration: %s\n", buf);
-  i++;
-  if (buf[++i]) printf(" \"%s\"", buf + i);	/* URL */
+  if (buf[i++] != '"') errexit("Incorrect DOCTYPE declaration: %s\n", buf);
+  /* write URL if present */
+  while (buf[i] == ' ') i++;
+  if (buf[i]) {
+    if (!has_fpi) printf(" SYSTEM");
+    printf(" \"%s\"", buf + i);	/* URL */
+  }
   printf(">");
 }
 
