@@ -1,5 +1,5 @@
 /*
- * xmlns - expand XML Namespace prefixes
+ * hxxmlns - expand XML Namespace prefixes
  *
  * Expand all element and attribute names to "global names" by
  * expanding the prefix. All names will be printed as "{URL}name".
@@ -11,7 +11,7 @@
  *
  * Author: Bert Bos
  * Created: 22 Mar 2000
- * Version: $Id: hxxmlns.c,v 1.1 2008/08/17 13:55:39 bbos Exp $
+ * Version: $Id: hxxmlns.c,v 1.2 2010/07/12 17:26:33 bbos Exp $
  *
  **/
 #include <config.h>
@@ -197,9 +197,10 @@ void handle_text(void *clientdata, string text)
 void handle_decl(void *clientdata, string gi, string fpi, string url)
 {
   if (do_decls) {
-    if (!fpi) printf("<!DOCTYPE %s SYSTEM \"%s\">", gi, url);
-    else if (!url) printf("<!DOCTYPE %s PUBLIC \"%s\">", gi, fpi);
-    else printf("<!DOCTYPE %s PUBLIC \"%s\" \"%s\">", gi, fpi, url);
+    printf("<!DOCTYPE %s", gi);
+    if (fpi) printf(" PUBLIC \"%s\">", fpi);
+    if (url) printf(" %s\"%s\">", fpi ? "" : "SYSTEM ", url);
+    printf(">");
   }
   free(gi);
   if (fpi) free(fpi);
