@@ -1,7 +1,7 @@
 :
 trap 'rm $TMP1 $TMP2' 0
-TMP1=`mktemp` || exit 1
-TMP2=`mktemp` || exit 1
+TMP1=`mktemp /tmp/tmp.XXXXXXXXXX` || exit 1
+TMP2=`mktemp /tmp/tmp.XXXXXXXXXX` || exit 1
 
 ./hxref >$TMP1 <<-EOF
 	<p><dfn>term</dfn> is referenced twice:
