@@ -492,9 +492,9 @@ static void dump2(Tree n)
     case Comment: printf("<!--%s-->", n->text); break;
     case Declaration:
       printf("<!DOCTYPE %s", n->name);
-      if (n->text) printf(" \"%s\"", n->text); else printf(" SYSTEM");
-      if (n->url) printf(" \"%s\"", n->url);
-      printf(">\n");
+      if (n->text) printf(" PUBLIC \"%s\">", n->text);
+      if (n->url) printf(" %s\"%s\">", n->text ? "" : "SYSTEM ", n->url);
+      printf(">");
       break;
     case Procins: printf("<?%s>", n->text); break;
     case Element:
