@@ -3,7 +3,7 @@
  *
  * Assumes the strings are encoded in UTF-8
  *
- * Copyright  1994-2000 World Wide Web Consortium
+ * Copyright  1994-2011 World Wide Web Consortium
  * See http://www.w3.org/Consortium/Legal/copyright-software
  *
  * Author: Bert Bos <bert@w3.org>
@@ -83,12 +83,31 @@ EXPORT void URL_dispose(URL url)
 /* URL_new -- create a new URL struct; return NULL if not a valid URL */
 EXPORT URL URL_new(const conststring url)
 {
-  static const string pat =
-    "^(([^:/?#]+):)?(//(([^/?#:@]*)?(:([^/?#:@]*))?@)?([^/?#:]*)(:([0-9]*))?)?([^?#]*)(\\?([^#]*))?(#(.*))?$";
-  /*  12        2 1 3  45         5 6 7         76  4 8        89 A      A9 3 B      BC   D     DC E F  FE
-   *
-   * 2 = proto, 5 = user, 7 = password, 8 = machine, A = port, B = path,
-   * D = query, F = fragment
+#define PROTO    "([^:/?#]+)"
+  /*              2--------2						*/
+#define USER     "([^/?#@:[]*)"
+  /*              5----------5						*/
+#define PASSWORD "([^/?#@[]*)"
+  /*              7---------7						*/
+#define HOST     "(([^/?#:[]+)|\\[([0-9a-fA-F:]*)])?"
+  /*              89---------9----A-------------A-8			*/
+#define PORT     "([^/?#]*)"
+  /*              C-------C						*/
+#define AUTH     "(" USER "(:" PASSWORD ")?@)?" HOST "(:" PORT ")?"
+  /*              4--5--5--6---7------7--6--4   8--8  B---C--C--B	*/
+#define PATH     "([^?#[]*)"
+  /*              D------D						*/
+#define QUERY    "([^#]*)"
+  /*              F---F							*/
+#define FRAGM    "(.*)"
+  /*              H--H							*/
+
+#define PAT  "(" PROTO ":)?(//" AUTH ")?" PATH "(\\?" QUERY ")?(#" FRAGM ")?"
+  /*          1  2---2   1 3          3   D--D  E     F---F  E G   H---H  G */
+
+   /*
+   * 2 = proto, 5 = user, 7 = password, 9/A = machine, C = port, D = path,
+   * F = query, H = fragment
    */
 # define MAXSUB 18
   static regex_t re;
@@ -100,7 +119,7 @@ EXPORT URL URL_new(const conststring url)
   
   /* Compile the regexp, only once */
   if (! initialized) {
-    assert(regcomp(&re, pat, REG_EXTENDED) == 0); /* Could be memory, though... */
+    assert(regcomp(&re, PAT, REG_EXTENDED) == 0); /* Could be memory... */
     initialized = 1;
   }
 
@@ -116,16 +135,19 @@ EXPORT URL URL_new(const conststring url)
     ? NULL : newnstring(url + pm[5].rm_so, pm[5].rm_eo - pm[5].rm_so);
   result->password = pm[7].rm_so == -1
     ? NULL : newnstring(url + pm[7].rm_so, pm[7].rm_eo - pm[7].rm_so);
-  result->machine = pm[8].rm_so == -1
-    ? NULL : newnstring(url + pm[8].rm_so, pm[8].rm_eo - pm[8].rm_so);
-  result->port = pm[10].rm_so == -1
-    ? NULL : newnstring(url + pm[10].rm_so, pm[10].rm_eo - pm[10].rm_so);
-  result->path = pm[11].rm_so == -1
-    ? NULL : newnstring(url + pm[11].rm_so, pm[11].rm_eo - pm[11].rm_so);
-  result->query = pm[13].rm_so == -1
+  result->machine = pm[9].rm_so != -1
+    ? newnstring(url + pm[9].rm_so, pm[9].rm_eo - pm[9].rm_so)
+    : pm[10].rm_so != -1
+    ? newnstring(url + pm[10].rm_so, pm[10].rm_eo - pm[10].rm_so)
+    : NULL;
+  result->port = pm[12].rm_so == -1
+    ? NULL : newnstring(url + pm[12].rm_so, pm[12].rm_eo - pm[12].rm_so);
+  result->path = pm[13].rm_so == -1
     ? NULL : newnstring(url + pm[13].rm_so, pm[13].rm_eo - pm[13].rm_so);
-  result->fragment = pm[15].rm_so == -1
+  result->query = pm[15].rm_so == -1
     ? NULL : newnstring(url + pm[15].rm_so, pm[15].rm_eo - pm[15].rm_so);
+  result->fragment = pm[17].rm_so == -1
+    ? NULL : newnstring(url + pm[17].rm_so, pm[17].rm_eo - pm[17].rm_so);
   return result;
 }
 
@@ -253,13 +275,13 @@ EXPORT URL URL_absolutize(const URL base, const URL url)
   newarray(s, (abs->proto ? strlen(abs->proto) + 1 : 0)
 	   + (abs->user ? strlen(abs->user) + 1 : 0)
 	   + (abs->password ? strlen(abs->password) + 1 : 0)
-	   + (abs->machine ? strlen(abs->machine) + 2 : 0)
+	   + (abs->machine ? strlen(abs->machine) + 4 : 0)
 	   + (abs->port ? strlen(abs->port) + 1 : 0)
 	   + (abs->path ? strlen(abs->path) : 0)
 	   + (abs->query ? strlen(abs->query) + 1 : 0)
 	   + (abs->fragment ? strlen(abs->fragment) + 1 : 0)
 	   + 1);
-  sprintf(s, "%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s",
+  sprintf(s, "%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s%s",
 	  abs->proto ? abs->proto : (string) "",
 	  abs->proto ? (string) ":" : (string) "",
 	  abs->machine ? (string) "//" : (string) "",
@@ -267,7 +289,9 @@ EXPORT URL URL_absolutize(const URL base, const URL url)
 	  abs->password ? (string) ":" : (string) "",
 	  abs->password ? abs->password : (string) "",
 	  abs->user ? (string) "@" : (string) "",
+	  abs->machine && strchr(abs->machine, ':') ? "[" : "",
 	  abs->machine ? abs->machine : (string) "",
+	  abs->machine && strchr(abs->machine, ':') ? "]" : "",
 	  abs->port ? (string) ":" : (string) "",
 	  abs->port ? abs->port : (string) "",
 	  abs->path ? abs->path : (string) "",
@@ -275,6 +299,7 @@ EXPORT URL URL_absolutize(const URL base, const URL url)
 	  abs->query ? abs->query : (string) "",
 	  abs->fragment ? (string) "#" : (string) "",
 	  abs->fragment ? abs->fragment : (string) "");
+  /* Instead of strchr() above, we could have an IPv6 flag. Necessary? */
   abs->full = utf8tohex(s);
   dispose(s);
 
